@@ -82,10 +82,6 @@ def check_and_reset_args(args: Namespace):
             wait_for_answer()
             print("Let's rock!")
 
-        # Give user a warning
-        # raise argparse.ArgumentTypeError('You must specify the \'-c/--close-all\' flags to close the current '
-        #                                  'session before restoring a session.')
-
 
 def wait_for_answer():
     answer = input("Please type your answer (y/N): ")
@@ -113,7 +109,7 @@ def handle_arguments(args: Namespace):
     including_apps_with_multiple_windows = args.including_apps_with_multiple_windows
 
     if session_name_for_saving:
-        print(constants.Prompts.MSG_SAVE)
+        print(constants.Prompts.MSG_SAVE % session_name_for_saving)
         wait_for_answer()
         xsm = XSessionManager()
         xsm.save_session(session_name_for_saving)
@@ -143,14 +139,16 @@ def handle_arguments(args: Namespace):
             xsm.restore_session(pop_up_a_dialog_to_restore, restoring_interval)
 
     if list_sessions:
+        print()
         import os
-        walk: (list, list, str) = os.walk(constants.Locations.BASE_LOCATION_OF_SESSIONS)
+        walk = os.walk(constants.Locations.BASE_LOCATION_OF_SESSIONS)
+        num = 0
         for root, dirs, files in walk:
-            # files.sort()
             for file in files:
                 with open(Path(root, file), 'r') as f:
+                    num = num + 1
                     namespace_objs: XSessionConfig = json.load(f, object_hook=lambda d: Namespace(**d))
-                    print(namespace_objs.session_name, namespace_objs.session_create_time, str(Path(root, file)),
+                    print(str(num) +'. ' + namespace_objs.session_name, namespace_objs.session_create_time, str(Path(root, file)),
                           sep='  ')
 
             break
@@ -166,9 +164,9 @@ def handle_arguments(args: Namespace):
         count = 0
         with open(session_path, 'r') as file:
             namespace_objs: XSessionConfig = json.load(file, object_hook=lambda d: Namespace(**d))
-            print('session name: %s' % namespace_objs.session_name)
-            print('location: %s' % str(session_path))
-            print('created at: %s' % namespace_objs.session_create_time)
+            print('Session Name: %s' % namespace_objs.session_name)
+            print('Created At: %s' % namespace_objs.session_create_time)
+            print('Location: %s' % str(session_path))
 
             x_session_config_objects: List[XSessionConfigObject] = namespace_objs.x_session_config_objects
             # Print data according to declared order
