@@ -92,6 +92,7 @@ class XSessionManager:
         for idx, sd in enumerate(x_session_config_objects):
             try:
                 process = psutil.Process(sd.pid)
+                sd.username = process.username()
                 sd.cmd = process.cmdline()
                 sd.app_name = wnck_utils.get_app_name(sd.window_id_the_int_type)
                 sd.process_create_time = datetime.datetime.fromtimestamp(process.create_time()).strftime("%Y-%m-%d %H:%M:%S")
@@ -164,13 +165,9 @@ class XSessionManager:
         with open(session_path, 'r') as file:
             print('Restoring session located [%s] ' % session_path)
             namespace_objs: XSessionConfig = json.load(file, object_hook=lambda d: Namespace(**d))
-            # Note: os.fork() does not support the Windows
+            # Note: os.fork() does not support MS Windows
             pid = os.fork()
-            # Run command lines in the child process
-            # TODO 1. I'm not sure if this method works well and is the best practice
-            # TODO 2. Must run in the child process or receive this error:
-            # Gdk-Message: 23:23:24.613: main.py: Fatal IO error 11 (Resource temporarily unavailable) on X server :1
-            # Not know the root cause
+            # Launch APPs in the child process
             if pid == 0:
                 x_session_config_objects: List[XSessionConfigObject] = namespace_objs.x_session_config_objects
                 # Remove duplicates according to pid
@@ -202,7 +199,7 @@ class XSessionManager:
                     x_session_config_object.pid = None
 
                 max_desktop_number = self._get_max_desktop_number(x_session_config_objects)
-                with self.create_enough_workspaces(max_desktop_number):
+                with wnck_utils.create_enough_workspaces(max_desktop_number):
                     x_session_config_objects_copy.sort(key=attrgetter('memory_percent'), reverse=True)
                     restore_thread = restore_sessions_async(x_session_config_objects_copy)
                     restore_thread.join()
@@ -238,7 +235,6 @@ class XSessionManager:
                     namespace_obj.pid = process.pid
                     succeeded_restores.append(index)
                     self.move_window(session_name)
-                    # print('Success to restore application:     [%s]' % app_name)
 
                     # Wait some time, in case of freezing the entire system
                     sleep(restoring_interval)
@@ -273,41 +269,9 @@ class XSessionManager:
         while retry_count_down > 0:
             retry_count_down = retry_count_down - 1
             sleep(1.5)
-            # xsm = XSessionManager(self.session_filters)
-            # xsm._suppress_log_if_already_in_workspace = True
-            # xsm.move_window(session_name)
             self._suppress_log_if_already_in_workspace = True
             self.move_window(session_name)
 
-    @contextmanager
-    def create_enough_workspaces(self, max_desktop_number: int):
-        # Create enough workspaces
-        if wnck_utils.is_gnome():
-            workspace_count = wnck_utils.get_workspace_count()
-            if workspace_count >= max_desktop_number:
-                yield
-                return
-
-            gsettings = gio_utils.GSettings(access_dynamic_workspaces=True, access_num_workspaces=True)
-            if gsettings.is_dynamic_workspaces():
-                gsettings.disable_dynamic_workspaces()
-                try:
-                    gsettings.set_workspaces_number(max_desktop_number)
-                    try:
-                        yield
-                    finally:
-                        gsettings.enable_dynamic_workspaces()
-                except Exception as e:
-                    import traceback
-                    print(traceback.format_exc())
-            else:
-                workspaces_number = gsettings.get_workspaces_number()
-                if max_desktop_number > workspaces_number:
-                    gsettings.set_workspaces_number(max_desktop_number)
-                yield
-        else:
-            yield
-
     def close_windows(self, including_apps_with_multiple_windows: bool = False):
         sessions: List[XSessionConfigObject] = \
             self.get_session_details(remove_duplicates_by_pid=False,
@@ -357,7 +321,7 @@ class XSessionManager:
             return
 
         max_desktop_number = self._get_max_desktop_number(x_session_config_objects)
-        with self.create_enough_workspaces(max_desktop_number):
+        with wnck_utils.create_enough_workspaces(max_desktop_number):
             for namespace_obj in x_session_config_objects:
                 try:
                     self._move_window(namespace_obj, need_retry=False)
@@ -365,12 +329,6 @@ class XSessionManager:
                     import traceback
                     print(traceback.format_exc())
 
-        # Some apps may not be launched successfully due to any possible reason
-        # if len(self._windows_can_not_be_moved) > 0:
-        #     print('Those windows cannot be moved: ')
-        #     for w in self._windows_can_not_be_moved:
-        #         print(w)
-
     def _get_max_desktop_number(self, x_session_config_objects):
         return max([x_session_config_object.desktop_number
                     for x_session_config_object in x_session_config_objects]) + 1
@@ -412,7 +370,6 @@ class XSessionManager:
 
                     if self._is_same_cmd(p, cmd):
                         pids.append(p.pid)
-                        # break
 
             if len(pids) == 0:
                 self._windows_can_not_be_moved.append(saved_window)
@@ -452,7 +409,6 @@ class XSessionManager:
                             continue
                         moving_windows.append(running_window)
                         no_need_to_move = False
-                        # break
                 else:
                     no_need_to_move = False
 
